//Source file: BodyPartDescription.java
//Date: March 2007
//Multi Media Messaging for for 3GPP TS 29.198-15 V6.5.0

package org.csapi.jr.se.mmm;

/**
 * Defines a sequence of data elements that specify the properties of a body part.
 * 
 */
public final class BodyPartDescription implements java.io.Serializable {

    private String contentDescription;
    private int contentSize;
    private String contentType;
    private String contentTransferEncoding;
    private String contentID;
    private String contentDisposition;
    private String partID;
    private int nestingLevel;

    /**
     * Creates a new BodyPartDescription instance.
     */
    public BodyPartDescription () {}

    /**
     * Creates a new BodyPartDescription instance.
     * @param _contentDescription   The contents of the field shall be interpreted as the RFC 2045 Content-Description field body.
     * @param _contentSize   This field specifies the length of the body part content in bytes.
     * @param _contentType   The contents of the field shall be interpreted as the RFC 2045 Content-Type field body.
     * @param _contentTransferEncoding   The contents of the field shall be interpreted as the RFC 2045 Content-Transfer-Encoding field body.
     * @param _contentID   The contents of the field shall be interpreted as the RFC 2045 Content-ID field body.
     * @param _contentDisposition   The contents of the field shall be interpreted as the RFC 2183 Content-Disposition field body.
     * @param _partID   Identifies the body part uniquely within the message. This identifier is created by the System and shall always be the same for the same message, whether a structure was listed with a nesting level of n or n+1 should not make a difference.
     * @param _nestingLevel   Specifies how deep the part is nested within the structure.
     */
    public BodyPartDescription (String _contentDescription, int _contentSize, String _contentType, String _contentTransferEncoding, String _contentID, String _contentDisposition, String _partID, int _nestingLevel) {

        this.contentDescription = _contentDescription;
        this.contentSize = _contentSize;
        this.contentType = _contentType;
        this.contentTransferEncoding = _contentTransferEncoding;
        this.contentID = _contentID;
        this.contentDisposition = _contentDisposition;
        this.partID = _partID;
        this.nestingLevel = _nestingLevel;
    }

    /**
     * This method returns a contentDescription.
     * 
     * @return a String value
     */
    public String getContentDescription() {
        return contentDescription;
    }

    /**
     * This method returns a contentSize.
     * 
     * @return a int value
     */
    public int getContentSize() {
        return contentSize;
    }

    /**
     * This method returns a contentType.
     * 
     * @return a String value
     */
    public String getContentType() {
        return contentType;
    }

    /**
     * This method returns a contentTransferEncoding.
     * 
     * @return a String value
     */
    public String getContentTransferEncoding() {
        return contentTransferEncoding;
    }

    /**
     * This method returns a contentID.
     * 
     * @return a String value
     */
    public String getContentID() {
        return contentID;
    }

    /**
     * This method returns a contentDisposition.
     * 
     * @return a String value
     */
    public String getContentDisposition() {
        return contentDisposition;
    }

    /**
     * This method returns a partID.
     * 
     * @return a String value
     */
    public String getPartID() {
        return partID;
    }

    /**
     * This method returns a nestingLevel.
     * 
     * @return a int value
     */
    public int getNestingLevel() {
        return nestingLevel;
    }


    /**
     * This method sets a contentDescription.
     */ 
    public void setContentDescription(String contentDescription) {
        this.contentDescription = contentDescription;
    }

    /**
     * This method sets a contentSize.
     */ 
    public void setContentSize(int contentSize) {
        this.contentSize = contentSize;
    }

    /**
     * This method sets a contentType.
     */ 
    public void setContentType(String contentType) {
        this.contentType = contentType;
    }

    /**
     * This method sets a contentTransferEncoding.
     */ 
    public void setContentTransferEncoding(String contentTransferEncoding) {
        this.contentTransferEncoding = contentTransferEncoding;
    }

    /**
     * This method sets a contentID.
     */ 
    public void setContentID(String contentID) {
        this.contentID = contentID;
    }

    /**
     * This method sets a contentDisposition.
     */ 
    public void setContentDisposition(String contentDisposition) {
        this.contentDisposition = contentDisposition;
    }

    /**
     * This method sets a partID.
     */ 
    public void setPartID(String partID) {
        this.partID = partID;
    }

    /**
     * This method sets a nestingLevel.
     */ 
    public void setNestingLevel(int nestingLevel) {
        this.nestingLevel = nestingLevel;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof BodyPartDescription)) {
            return false;
        } 
        BodyPartDescription bodyPartDescription = (BodyPartDescription) o;
        if ((this.contentDescription != null) && (bodyPartDescription.contentDescription != null)) {
            if(!(this.contentDescription.equals(bodyPartDescription.contentDescription)))  {
                return false;
            }
        }
        if(!(this.contentSize == bodyPartDescription.contentSize)) {
            return false;
        }
        if ((this.contentType != null) && (bodyPartDescription.contentType != null)) {
            if(!(this.contentType.equals(bodyPartDescription.contentType)))  {
                return false;
            }
        }
        if ((this.contentTransferEncoding != null) && (bodyPartDescription.contentTransferEncoding != null)) {
            if(!(this.contentTransferEncoding.equals(bodyPartDescription.contentTransferEncoding)))  {
                return false;
            }
        }
        if ((this.contentID != null) && (bodyPartDescription.contentID != null)) {
            if(!(this.contentID.equals(bodyPartDescription.contentID)))  {
                return false;
            }
        }
        if ((this.contentDisposition != null) && (bodyPartDescription.contentDisposition != null)) {
            if(!(this.contentDisposition.equals(bodyPartDescription.contentDisposition)))  {
                return false;
            }
        }
        if ((this.partID != null) && (bodyPartDescription.partID != null)) {
            if(!(this.partID.equals(bodyPartDescription.partID)))  {
                return false;
            }
        }
        if(!(this.nestingLevel == bodyPartDescription.nestingLevel)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // BodyPartDescription

