//Source file: MessageDescription.java
//Date: March 2007
//Multi Media Messaging for for 3GPP TS 29.198-15 V6.5.0

package org.csapi.jr.se.mmm;

/**
 * Specifies the properties of a message.
 * 
 */
public final class MessageDescription implements java.io.Serializable {

    private String messageID;
    private org.csapi.jr.se.Address from;
    private org.csapi.jr.se.Address[] to;
    private String subject;
    private String receivedDate;
    private int size;

    /**
     * Creates a new MessageDescription instance.
     */
    public MessageDescription () {}

    /**
     * Creates a new MessageDescription instance.
     * @param _messageID   This is the messageID as it is used on the API to identify a message. This should not be confused with the RFC 822 "Message-ID" field body. The latter can be obtained with  getMessageHeadersReq().The messageID used on the API is persistent over sessions and at least unique within the context of a mailbox. 
     * @param _from   The address of the sender of the message
     * @param _to   A set of addresses representing the primary recipients of the message. 
     * @param _subject   Specifies the subject of the message. 
     * @param _receivedDate   Specifies the date/time that the message was received by the messaging system.  
     * @param _size   Specifies the size of the message in bytes. 
     */
    public MessageDescription (String _messageID, org.csapi.jr.se.Address _from, org.csapi.jr.se.Address[] _to, String _subject, String _receivedDate, int _size) {

        this.messageID = _messageID;
        this.from = _from;
        this.to = _to;
        this.subject = _subject;
        this.receivedDate = _receivedDate;
        this.size = _size;
    }

    /**
     * This method returns a messageID.
     * 
     * @return a String value
     */
    public String getMessageID() {
        return messageID;
    }

    /**
     * This method returns a from.
     * 
     * @return a org.csapi.jr.se.Address value
     */
    public org.csapi.jr.se.Address getFrom() {
        return from;
    }

    /**
     * This method returns a to.
     * 
     * @return a org.csapi.jr.se.Address[] value
     */
    public org.csapi.jr.se.Address[] getTo() {
        return to;
    }

    /**
     * This method returns a subject.
     * 
     * @return a String value
     */
    public String getSubject() {
        return subject;
    }

    /**
     * This method returns a receivedDate.
     * 
     * @return a String value
     */
    public String getReceivedDate() {
        return receivedDate;
    }

    /**
     * This method returns a size.
     * 
     * @return a int value
     */
    public int getSize() {
        return size;
    }


    /**
     * This method sets a messageID.
     */ 
    public void setMessageID(String messageID) {
        this.messageID = messageID;
    }

    /**
     * This method sets a from.
     */ 
    public void setFrom(org.csapi.jr.se.Address from) {
        this.from = from;
    }

    /**
     * This method sets a to.
     */ 
    public void setTo(org.csapi.jr.se.Address[] to) {
        this.to = to;
    }

    /**
     * This method sets a subject.
     */ 
    public void setSubject(String subject) {
        this.subject = subject;
    }

    /**
     * This method sets a receivedDate.
     */ 
    public void setReceivedDate(String receivedDate) {
        this.receivedDate = receivedDate;
    }

    /**
     * This method sets a size.
     */ 
    public void setSize(int size) {
        this.size = size;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof MessageDescription)) {
            return false;
        } 
        MessageDescription messageDescription = (MessageDescription) o;
        if ((this.messageID != null) && (messageDescription.messageID != null)) {
            if(!(this.messageID.equals(messageDescription.messageID)))  {
                return false;
            }
        }
        if ((this.from != null) && (messageDescription.from != null)) {
            if(!(this.from.equals(messageDescription.from))) {
                return false;
            }
        }
        if(!(this.to == messageDescription.to))  {
            return false;
        }
        if ((this.subject != null) && (messageDescription.subject != null)) {
            if(!(this.subject.equals(messageDescription.subject)))  {
                return false;
            }
        }
        if(!(this.receivedDate == messageDescription.receivedDate))  {
            return false;
        }
        if(!(this.size == messageDescription.size)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // MessageDescription

