//Source file: NewMessageArrivedCriteria.java
//Date: March 2007
//Multi Media Messaging for for 3GPP TS 29.198-15 V6.5.0

package org.csapi.jr.se.mmm;

/**
 * Defines the Sequence of Data Elements that specify the criteria for a New Message Arrived event, for messages which are received outside the context of a mailbox.
 * 
 */
public final class NewMessageArrivedCriteria implements java.io.Serializable {

    private org.csapi.jr.se.AddressRange sourceAddress;
    private org.csapi.jr.se.AddressRange destinationAddress;
    private boolean createMultiMediaMessagingSession;

    /**
     * Creates a new NewMessageArrivedCriteria instance.
     */
    public NewMessageArrivedCriteria () {}

    /**
     * Creates a new NewMessageArrivedCriteria instance.
     * @param _sourceAddress   Defines the source address for which the notification is requested.
     * @param _destinationAddress   Defines the destination address or address range for which the notification is requested.
     * @param _createMultiMediaMessagingSession   Used by the application to indicate if the SCF should create an instance of IpMultiMediaMessaging upon receipt of an event which matches these criteria.
     */
    public NewMessageArrivedCriteria (org.csapi.jr.se.AddressRange _sourceAddress, org.csapi.jr.se.AddressRange _destinationAddress, boolean _createMultiMediaMessagingSession) {

        this.sourceAddress = _sourceAddress;
        this.destinationAddress = _destinationAddress;
        this.createMultiMediaMessagingSession = _createMultiMediaMessagingSession;
    }

    /**
     * This method returns a sourceAddress.
     * 
     * @return a org.csapi.jr.se.AddressRange value
     */
    public org.csapi.jr.se.AddressRange getSourceAddress() {
        return sourceAddress;
    }

    /**
     * This method returns a destinationAddress.
     * 
     * @return a org.csapi.jr.se.AddressRange value
     */
    public org.csapi.jr.se.AddressRange getDestinationAddress() {
        return destinationAddress;
    }

    /**
     * This method returns a createMultiMediaMessagingSession.
     * 
     * @return a boolean value
     */
    public boolean getCreateMultiMediaMessagingSession() {
        return createMultiMediaMessagingSession;
    }


    /**
     * This method sets a sourceAddress.
     */ 
    public void setSourceAddress(org.csapi.jr.se.AddressRange sourceAddress) {
        this.sourceAddress = sourceAddress;
    }

    /**
     * This method sets a destinationAddress.
     */ 
    public void setDestinationAddress(org.csapi.jr.se.AddressRange destinationAddress) {
        this.destinationAddress = destinationAddress;
    }

    /**
     * This method sets a createMultiMediaMessagingSession.
     */ 
    public void setCreateMultiMediaMessagingSession(boolean createMultiMediaMessagingSession) {
        this.createMultiMediaMessagingSession = createMultiMediaMessagingSession;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof NewMessageArrivedCriteria)) {
            return false;
        } 
        NewMessageArrivedCriteria newMessageArrivedCriteria = (NewMessageArrivedCriteria) o;
        if ((this.sourceAddress != null) && (newMessageArrivedCriteria.sourceAddress != null)) {
            if(!(this.sourceAddress.equals(newMessageArrivedCriteria.sourceAddress))) {
                return false;
            }
        }
        if ((this.destinationAddress != null) && (newMessageArrivedCriteria.destinationAddress != null)) {
            if(!(this.destinationAddress.equals(newMessageArrivedCriteria.destinationAddress))) {
                return false;
            }
        }
        if(!(this.createMultiMediaMessagingSession == newMessageArrivedCriteria.createMultiMediaMessagingSession)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // NewMessageArrivedCriteria

